@@ -15,7 +15,7 @@ Version 0.05
 
 =cut
 
-our $VERSION = '0.05_02';
+our $VERSION = 0.05;
 
 =head1 SYNOPSIS
 
@@ -46,19 +46,11 @@ Creates a new object. The specified must be a valid address or host name.
 sub new
 {
 	my($class, %args) = @_;
-
-	# If the protocol isn't specified, let's assume it's just HTTP.
-	if($args{host} !~/^http/)
-	{
-		$args{host} = 'http://'.$args{host};
-	}
-
 	my $self = {
 		host	  => $args{host},
 		ua 	  => LWP::UserAgent->new,
 		xml	  => XML::Twig->new,
-		uri	  => URI->new($args{host}),
-		resultset => '/fmi/xml/fmresultset.xml', # Entirely for dbnames();
+		resultset => '/fmi/xml/fmresultset.xml?', # Entirely for dbnames();
 	};
 
 	return bless $self;
@@ -111,46 +103,29 @@ sub dbnames
 
 }
 
-=head1 SEE ALSO
 
-L<Net::FileMaker::XML::Database>
 
-=cut
-
-# _request(query => $query, params => $params, resultset => $resultset, user => $user, pass => $pass)
+# _request(query => $query, resultset => $resultset, user => $user, pass => $pass)
 #
 # Performs a request to the FileMaker Server. The query and resultset keys are mandatory, 
 # however user and pass keys are not. The query should always be URI encoded.
 sub _request
 {
-        my ($self, %args) = @_;
+	my ($self, %args) = @_;
 
-        # Construct the URI
-        my $uri = $self->{uri}->clone;
-        $uri->path($args{resultset});
-        
-        my $url;
-	# This kind of defeats the purpose of using URI to begin with,
-        if($args{params})
+	# Everything in %args should be uri encoded.
+	my $url = $self->{host}.$args{resultset}.$args{query};
+
+	my $req = HTTP::Request->new(GET => $url);
+
+	if($args{user} && $args{pass})
 	{
-                $uri->query_form(%{$args{params}});
-                $url = $uri->as_string."&".$args{query};
-        }
-        else
-        {
-           $url = $uri->as_string."?".$args{query};
-        }
+		$req->authorization_basic( $args{user}, $args{pass});
+	}
 
-        my $req = HTTP::Request->new(GET => $url);
+	my $res = $self->{ua}->request($req);
 
-        if($args{user} && $args{pass})
-        {       
-                $req->authorization_basic( $args{user}, $args{pass});
-        }       
-
-        my $res = $self->{ua}->request($req);
-
-        return $res;
+	return $res;
 
 }
 
@@ -217,29 +192,10 @@ sub _compose_arrayref
 
 }
 
+=head1 SEE ALSO
 
-# _assert_param()
-#
-# Optional parameters sometimes validation to ensure they are correct.
-# Warnings are issued if a parameter name is somehow invalid.
-sub _assert_param
-{
-	my($self, $unclean_param, $acceptable_params) = @_;
-	my $param;
-
-	if($unclean_param =~/$acceptable_params/)
-	{
-		$param = $unclean_param;
-	}
-	else
-	{
-		# TODO: Localise this error message
-		warn "Invalid parameter specified - $unclean_param";
-	}
-
-
-	return $param;
-}
+L<Net::FileMaker::XML::Database>
 
+=cut
 
 1; # End of Net::FileMaker::XML;
